@@ -38,7 +38,7 @@ BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< const string >::type path(pathSEXP);
-    __result = wrap(read_directory(path));
+    __result = read_directory(path);
     return __result;
 END_RCPP
 }
@@ -99,7 +99,7 @@ BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< string >::type path_man(path_manSEXP);
-    __result = wrap(read_examples(path_man));
+    __result = read_examples(path_man);
     return __result;
 END_RCPP
 }
